/******************************************************************************
 * 
 * Copyright 2012 - 2013 Vektor Software.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 *****************************************************************************/


package com.vektorsoft.demux.android.core.app;

import android.content.Context;
import com.vektorsoft.demux.core.mva.DMXAbstractView;

/**
 * An implementation of {@link DMXView} for use on Android devices. This class implements some 
 * common methods to facilitate view creation.
 *
 * @author Vladimir Djurovic
 */
public abstract  class DMXAndroidAbstractView extends DMXAbstractView implements DMXAndroidView {
    
    /** Android application context. */
    protected Context context;

    
    @Override
    public void setContext(Context context) {
        this.context = context;
        createUI();
        
    }
    
    /**
     * <p>
     * Creates user interface for this view. This method is invoked from {@link #setContext(android.content.Context) } method
     * after context has been set, so view elements can be created.
     * </p>
     * <p>
     *  Subclasses should override this method to create view UI.
     * </p>
     */
    protected abstract void createUI();

}
